"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _uikitReactNativeFoundation = require("@sendbird/uikit-react-native-foundation");
var _uikitUtils = require("@sendbird/uikit-utils");
var _useContext = require("../../hooks/useContext");
var _SBUUtils = _interopRequireDefault(require("../../libs/SBUUtils"));
var _ChatFlatList = _interopRequireDefault(require("../ChatFlatList"));
var _ReactionAddons = require("../ReactionAddons");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } return n; }, _extends.apply(null, arguments); }
const ChannelMessageList = ({
  searchItem,
  hasNext,
  channel,
  onEditMessage,
  onReplyMessage,
  onReplyInThreadMessage,
  onDeleteMessage,
  onResendFailedMessage,
  onPressMediaMessage,
  onPressParentMessage,
  currentUserId,
  renderNewMessagesButton,
  renderScrollToBottomButton,
  renderMessage,
  messages,
  newMessages,
  enableMessageGrouping,
  onScrolledAwayFromBottom,
  scrolledAwayFromBottom,
  onBottomReached,
  onTopReached,
  flatListComponent,
  flatListProps,
  onPressNewMessagesButton,
  onPressScrollToBottomButton
}, ref) => {
  const {
    STRINGS
  } = (0, _useContext.useLocalization)();
  const {
    colors
  } = (0, _uikitReactNativeFoundation.useUIKitTheme)();
  const {
    show
  } = (0, _useContext.useUserProfile)();
  const safeAreaLayout = (0, _uikitUtils.useSafeAreaPadding)(['left', 'right']);
  const createMessagePressActions = useCreateMessagePressActions({
    channel,
    currentUserId,
    onEditMessage,
    onReplyMessage,
    onReplyInThreadMessage,
    onDeleteMessage,
    onResendFailedMessage,
    onPressMediaMessage
  });
  const renderItem = (0, _uikitUtils.useFreshCallback)(({
    item,
    index
  }) => {
    const {
      onPress,
      onLongPress,
      bottomSheetItem
    } = createMessagePressActions({
      message: item
    });
    return renderMessage({
      message: item,
      prevMessage: messages[index + 1],
      nextMessage: messages[index - 1],
      onPress,
      onLongPress,
      onPressParentMessage,
      onReplyInThreadMessage,
      onShowUserProfile: show,
      enableMessageGrouping,
      channel,
      currentUserId,
      focused: ((searchItem === null || searchItem === void 0 ? void 0 : searchItem.startingPoint) ?? -1) === item.createdAt,
      bottomSheetItem,
      isFirstItem: index === 0
    });
  });
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [{
      flex: 1,
      backgroundColor: colors.background
    }, safeAreaLayout]
  }, channel.isFrozen && /*#__PURE__*/_react.default.createElement(_uikitReactNativeFoundation.ChannelFrozenBanner, {
    style: styles.frozenBanner,
    text: STRINGS.LABELS.CHANNEL_MESSAGE_LIST_FROZEN
  }), /*#__PURE__*/_react.default.createElement(_ChatFlatList.default, _extends({
    flatListComponent: flatListComponent
  }, flatListProps, {
    onTopReached: onTopReached,
    onBottomReached: onBottomReached,
    onScrolledAwayFromBottom: onScrolledAwayFromBottom,
    ref: ref,
    data: messages,
    renderItem: renderItem,
    keyExtractor: _uikitUtils.messageKeyExtractor,
    contentContainerStyle: [
    // { minHeight: '100%', justifyContent: 'flex-end' },
    channel.isFrozen && styles.frozenListPadding, flatListProps === null || flatListProps === void 0 ? void 0 : flatListProps.contentContainerStyle]
  })), renderNewMessagesButton && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.newMsgButton, safeAreaLayout]
  }, renderNewMessagesButton({
    visible: newMessages.length > 0 && (hasNext() || scrolledAwayFromBottom),
    onPress: () => onPressNewMessagesButton(),
    newMessages
  })), renderScrollToBottomButton && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.scrollButton, safeAreaLayout]
  }, renderScrollToBottomButton({
    visible: hasNext() || scrolledAwayFromBottom,
    onPress: () => onPressScrollToBottomButton()
  })));
};
const useCreateMessagePressActions = ({
  channel,
  currentUserId,
  onResendFailedMessage,
  onEditMessage,
  onReplyMessage,
  onReplyInThreadMessage,
  onDeleteMessage,
  onPressMediaMessage
}) => {
  const handlers = (0, _useContext.useSBUHandlers)();
  const {
    colors
  } = (0, _uikitReactNativeFoundation.useUIKitTheme)();
  const {
    STRINGS
  } = (0, _useContext.useLocalization)();
  const toast = (0, _uikitReactNativeFoundation.useToast)();
  const {
    openSheet
  } = (0, _uikitReactNativeFoundation.useBottomSheet)();
  const {
    alert
  } = (0, _uikitReactNativeFoundation.useAlert)();
  const {
    clipboardService,
    fileService
  } = (0, _useContext.usePlatformService)();
  const {
    sbOptions
  } = (0, _useContext.useSendbirdChat)();
  const onResendFailure = error => {
    toast.show(STRINGS.TOAST.RESEND_MSG_ERROR, 'error');
    _uikitUtils.Logger.error(STRINGS.TOAST.RESEND_MSG_ERROR, error);
  };
  const onDeleteFailure = error => {
    toast.show(STRINGS.TOAST.DELETE_MSG_ERROR, 'error');
    _uikitUtils.Logger.error(STRINGS.TOAST.DELETE_MSG_ERROR, error);
  };
  const onCopyText = message => {
    if (message.isUserMessage()) {
      clipboardService.setString(message.message || '');
      toast.show(STRINGS.TOAST.COPY_OK, 'success');
    }
  };
  const onDownloadFile = message => {
    if (message.isFileMessage()) {
      if ((0, _uikitUtils.toMegabyte)(message.size) > 4) {
        toast.show(STRINGS.TOAST.DOWNLOAD_START, 'success');
      }
      fileService.save({
        fileUrl: message.url,
        fileName: message.name,
        fileType: message.type
      }).then(response => {
        toast.show(STRINGS.TOAST.DOWNLOAD_OK, 'success');
        _uikitUtils.Logger.log('File saved to', response);
      }).catch(err => {
        toast.show(STRINGS.TOAST.DOWNLOAD_ERROR, 'error');
        _uikitUtils.Logger.log('File save failure', err);
      });
    }
  };
  const onOpenFile = message => {
    if (message.isFileMessage()) {
      const fileType = (0, _uikitUtils.getFileType)(message.type || (0, _uikitUtils.getFileExtension)(message.name));
      if (['image', 'video', 'audio'].includes(fileType)) {
        var _handlers$onOpenFileU;
        onPressMediaMessage === null || onPressMediaMessage === void 0 || onPressMediaMessage(message, () => onDeleteMessage(message), (0, _uikitUtils.getAvailableUriFromFileMessage)(message));
        (_handlers$onOpenFileU = handlers.onOpenFileURL) === null || _handlers$onOpenFileU === void 0 || _handlers$onOpenFileU.call(handlers, message.url);
      } else {
        const openFile = handlers.onOpenFileURL ?? _SBUUtils.default.openURL;
        openFile(message.url);
      }
    }
  };
  const openSheetForFailedMessage = message => {
    openSheet({
      sheetItems: [{
        title: STRINGS.LABELS.CHANNEL_MESSAGE_FAILED_RETRY,
        onPress: () => onResendFailedMessage(message).catch(onResendFailure)
      }, {
        title: STRINGS.LABELS.CHANNEL_MESSAGE_FAILED_REMOVE,
        titleColor: colors.ui.dialog.default.none.destructive,
        onPress: () => alertForMessageDelete(message)
      }]
    });
  };
  const alertForMessageDelete = message => {
    alert({
      title: STRINGS.LABELS.CHANNEL_MESSAGE_DELETE_CONFIRM_TITLE,
      buttons: [{
        text: STRINGS.LABELS.CHANNEL_MESSAGE_DELETE_CONFIRM_CANCEL
      }, {
        text: STRINGS.LABELS.CHANNEL_MESSAGE_DELETE_CONFIRM_OK,
        style: 'destructive',
        onPress: () => {
          onDeleteMessage(message).catch(onDeleteFailure);
        }
      }]
    });
  };
  return ({
    message
  }) => {
    if (!message.isUserMessage() && !message.isFileMessage()) return {};
    const sheetItems = [];
    const menu = {
      copy: message => ({
        icon: 'copy',
        title: STRINGS.LABELS.CHANNEL_MESSAGE_COPY,
        onPress: () => onCopyText(message)
      }),
      edit: message => ({
        icon: 'edit',
        title: STRINGS.LABELS.CHANNEL_MESSAGE_EDIT,
        onPress: () => onEditMessage(message)
      }),
      delete: message => ({
        disabled: message.threadInfo ? message.threadInfo.replyCount > 0 : undefined,
        icon: 'delete',
        title: STRINGS.LABELS.CHANNEL_MESSAGE_DELETE,
        onPress: () => alertForMessageDelete(message)
      }),
      reply: message => ({
        disabled: Boolean(message.parentMessageId),
        icon: 'reply',
        title: STRINGS.LABELS.CHANNEL_MESSAGE_REPLY,
        onPress: () => onReplyMessage === null || onReplyMessage === void 0 ? void 0 : onReplyMessage(message)
      }),
      replyInThread: message => ({
        disabled: Boolean(message.parentMessageId),
        icon: 'thread',
        title: STRINGS.LABELS.CHANNEL_MESSAGE_THREAD,
        onPress: () => onReplyInThreadMessage === null || onReplyInThreadMessage === void 0 ? void 0 : onReplyInThreadMessage(message)
      }),
      download: message => ({
        icon: 'download',
        title: STRINGS.LABELS.CHANNEL_MESSAGE_SAVE,
        onPress: () => onDownloadFile(message)
      })
    };
    if (message.isUserMessage()) {
      sheetItems.push(menu.copy(message));
      if (!channel.isEphemeral) {
        if ((0, _uikitUtils.isMyMessage)(message, currentUserId) && message.sendingStatus === 'succeeded') {
          sheetItems.push(menu.edit(message));
          sheetItems.push(menu.delete(message));
        }
        if (channel.isGroupChannel()) {
          if (sbOptions.uikit.groupChannel.channel.replyType === 'thread' && onReplyInThreadMessage !== undefined) {
            sheetItems.push(menu.replyInThread(message));
          } else if (sbOptions.uikit.groupChannel.channel.replyType === 'quote_reply') {
            sheetItems.push(menu.reply(message));
          }
        }
      }
    }
    if (message.isFileMessage()) {
      if (!(0, _uikitUtils.isVoiceMessage)(message)) {
        sheetItems.push(menu.download(message));
      }
      if (!channel.isEphemeral) {
        if ((0, _uikitUtils.isMyMessage)(message, currentUserId) && message.sendingStatus === 'succeeded') {
          sheetItems.push(menu.delete(message));
        }
        if (channel.isGroupChannel()) {
          if (sbOptions.uikit.groupChannel.channel.replyType === 'thread' && onReplyInThreadMessage !== undefined) {
            sheetItems.push(menu.replyInThread(message));
          } else if (sbOptions.uikit.groupChannel.channel.replyType === 'quote_reply') {
            sheetItems.push(menu.reply(message));
          }
        }
      }
    }
    const configs = sbOptions.uikitWithAppInfo.groupChannel.channel;
    const bottomSheetItem = {
      sheetItems,
      HeaderComponent: (0, _uikitUtils.shouldRenderReaction)(channel, channel.isGroupChannel() && (channel.isSuper ? configs.enableReactionsSupergroup : configs.enableReactions)) ? ({
        onClose
      }) => /*#__PURE__*/_react.default.createElement(_ReactionAddons.ReactionAddons.BottomSheet, {
        message: message,
        channel: channel,
        onClose: onClose
      }) : undefined
    };
    switch (true) {
      case message.sendingStatus === 'pending':
        {
          return {
            onPress: undefined,
            onLongPress: undefined,
            bottomSheetItem: undefined
          };
        }
      case message.sendingStatus === 'failed':
        {
          return {
            onPress: () => onResendFailedMessage(message).catch(onResendFailure),
            onLongPress: () => openSheetForFailedMessage(message),
            bottomSheetItem
          };
        }
      case message.isFileMessage():
        {
          return {
            onPress: () => onOpenFile(message),
            onLongPress: () => openSheet(bottomSheetItem),
            bottomSheetItem
          };
        }
      default:
        {
          return {
            onPress: undefined,
            onLongPress: () => openSheet(bottomSheetItem),
            bottomSheetItem
          };
        }
    }
  };
};
const styles = (0, _uikitReactNativeFoundation.createStyleSheet)({
  frozenBanner: {
    position: 'absolute',
    zIndex: 999,
    top: 8,
    start: 8,
    end: 8
  },
  frozenListPadding: {
    paddingBottom: 32
  },
  newMsgButton: {
    position: 'absolute',
    zIndex: 999,
    bottom: 10,
    alignSelf: 'center'
  },
  scrollButton: {
    position: 'absolute',
    zIndex: 998,
    bottom: 10,
    end: 16
  }
});

// NOTE: Due to Generic inference is not working on forwardRef, we need to cast it as typeof ChannelMessageList and implicit `ref` prop
var _default = exports.default = /*#__PURE__*/_react.default.forwardRef(ChannelMessageList);
//# sourceMappingURL=index.js.map