"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _reactNativeZoomableView = require("@openspacelabs/react-native-zoomable-view");
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _uikitReactNativeFoundation = require("@sendbird/uikit-react-native-foundation");
var _uikitUtils = require("@sendbird/uikit-utils");
var _useContext = require("../../hooks/useContext");
var _SBUUtils = _interopRequireDefault(require("../../libs/SBUUtils"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } return n; }, _extends.apply(null, arguments); }
const FileViewerContent = ({
  type,
  src,
  topInset = 0,
  bottomInset = 0,
  maxZoom = 4,
  minZoom = 1,
  onPress
}) => {
  const [loading, setLoading] = (0, _react.useState)(true);
  const {
    defaultHeight
  } = (0, _uikitReactNativeFoundation.useHeaderStyle)();
  const {
    mediaService
  } = (0, _useContext.usePlatformService)();
  const {
    palette
  } = (0, _uikitReactNativeFoundation.useUIKitTheme)();
  const source = {
    uri: src
  };
  const onLoadEnd = () => setLoading(false);
  const mediaViewer = (0, _uikitUtils.useIIFE)(() => {
    switch (type) {
      case 'image':
        {
          return /*#__PURE__*/_react.default.createElement(ZoomableImageView, {
            source: source,
            style: _reactNative.StyleSheet.absoluteFill,
            resizeMode: 'contain',
            onLoadEnd: onLoadEnd,
            zoomProps: {
              minZoom,
              maxZoom,
              onTouchEnd: onPress
            }
          });
        }
      case 'video':
      case 'audio':
        {
          return /*#__PURE__*/_react.default.createElement(mediaService.VideoComponent, {
            source: source,
            style: [_reactNative.StyleSheet.absoluteFill, {
              top: topInset,
              bottom: defaultHeight + bottomInset
            }],
            resizeMode: 'contain',
            onLoad: onLoadEnd
          });
        }
      default:
        {
          return null;
        }
    }
  });
  return /*#__PURE__*/_react.default.createElement(_uikitReactNativeFoundation.Box, {
    style: styles.container
  }, mediaViewer, loading && /*#__PURE__*/_react.default.createElement(_uikitReactNativeFoundation.LoadingSpinner, {
    style: {
      position: 'absolute'
    },
    size: 40,
    color: palette.primary300
  }));
};
const ZoomableImageView = ({
  zoomProps,
  ...props
}) => {
  const {
    width,
    height
  } = (0, _reactNative.useWindowDimensions)();
  const imageSize = (0, _react.useRef)();
  const [contentSizeProps, setContentSizeProps] = (0, _react.useState)({
    contentWidth: width,
    contentHeight: height
  });
  (0, _react.useLayoutEffect)(() => {
    _SBUUtils.default.safeRun(async () => {
      if (props.source.uri) {
        const image = imageSize.current ?? (await _SBUUtils.default.getImageSize(props.source.uri));
        imageSize.current = image;
        const viewRatio = width / height;
        const imageRatio = image.width / image.height;
        const fitDirection = viewRatio > imageRatio ? 'height' : 'width';
        const ratio = fitDirection === 'height' ? height / image.height : width / image.width;
        const actualSize = {
          width: image.width * ratio,
          height: image.height * ratio
        };
        setContentSizeProps({
          contentWidth: actualSize.width,
          contentHeight: actualSize.height
        });
      }
    });
  }, [props.source.uri, width, height]);
  return /*#__PURE__*/_react.default.createElement(_reactNativeZoomableView.ReactNativeZoomableView, _extends({
    visualTouchFeedbackEnabled: false,
    style: {
      width,
      height
    },
    initialZoom: 1
  }, contentSizeProps, zoomProps), /*#__PURE__*/_react.default.createElement(_uikitReactNativeFoundation.Image, props));
};
const styles = (0, _uikitReactNativeFoundation.createStyleSheet)({
  container: {
    zIndex: 0,
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center'
  }
});
var _default = exports.default = FileViewerContent;
//# sourceMappingURL=FileViewerContent.js.map