"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _uikitReactNativeFoundation = require("@sendbird/uikit-react-native-foundation");
var _uikitTools = require("@sendbird/uikit-tools");
var _uikitUtils = require("@sendbird/uikit-utils");
var _constants = require("../../constants");
var _useContext = require("../../hooks/useContext");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const BottomSheetReactionAddon = ({
  onClose,
  message,
  channel
}) => {
  const {
    emojiManager,
    currentUser,
    sdk
  } = (0, _useContext.useSendbirdChat)();
  const {
    updateReactionFocusedItem,
    openReactionList
  } = (0, _useContext.useReaction)();
  const {
    colors
  } = (0, _uikitReactNativeFoundation.useUIKitTheme)();
  const safeArea = (0, _uikitUtils.useSafeAreaPadding)(['left', 'right']);
  (0, _uikitTools.useGroupChannelHandler)(sdk, {
    async onReactionUpdated(eventChannel, event) {
      if ((channel === null || channel === void 0 ? void 0 : channel.url) === eventChannel.url && event.messageId === (message === null || message === void 0 ? void 0 : message.messageId)) {
        const msg = await sdk.message.getMessage({
          includeReactions: true,
          messageId: message.messageId,
          channelUrl: message.channelUrl,
          channelType: message.channelType
        });
        if (msg) updateReactionFocusedItem({
          message: msg
        });
      }
    }
  });
  const emojiAll = emojiManager.allEmoji.slice(0, 5);
  const color = colors.ui.reaction.default;
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.container, {
      marginStart: safeArea.paddingStart,
      marginEnd: safeArea.paddingEnd
    }]
  }, emojiAll.map(({
    key,
    url
  }) => {
    var _message$reactions;
    const reactionUserIds = (message === null || message === void 0 || (_message$reactions = message.reactions) === null || _message$reactions === void 0 || (_message$reactions = _message$reactions.find(it => it.key === key)) === null || _message$reactions === void 0 ? void 0 : _message$reactions.userIds) ?? [];
    const currentUserIdx = reactionUserIds.indexOf((currentUser === null || currentUser === void 0 ? void 0 : currentUser.userId) ?? _constants.UNKNOWN_USER_ID);
    const reacted = currentUserIdx > -1;
    const onPress = async () => {
      const action = (message, key) => {
        return reacted ? channel.deleteReaction(message, key) : channel.addReaction(message, key);
      };
      await action(message, key).catch(error => {
        _uikitUtils.Logger.warn('Failed to reaction', error);
      }).finally(() => {
        onClose();
      });
    };
    return /*#__PURE__*/_react.default.createElement(_reactNative.Pressable, {
      key: key,
      onPress: onPress,
      style: ({
        pressed
      }) => [styles.button, {
        backgroundColor: reacted || pressed ? color.selected.background : color.enabled.background
      }]
    }, /*#__PURE__*/_react.default.createElement(_uikitReactNativeFoundation.Image, {
      source: {
        uri: url
      },
      style: styles.emoji
    }));
  }), /*#__PURE__*/_react.default.createElement(_reactNative.Pressable, {
    onPress: async () => {
      await onClose();
      openReactionList({
        channel,
        message
      });
    },
    style: ({
      pressed
    }) => [styles.button, {
      backgroundColor: pressed ? color.selected.background : color.enabled.background
    }]
  }, /*#__PURE__*/_react.default.createElement(_uikitReactNativeFoundation.Icon, {
    icon: 'emoji-more',
    style: styles.emoji,
    color: colors.onBackground03
  })));
};
const styles = (0, _uikitReactNativeFoundation.createStyleSheet)({
  container: {
    paddingTop: 12,
    paddingBottom: 16,
    paddingHorizontal: 18,
    flexDirection: 'row',
    justifyContent: 'space-between'
  },
  button: {
    width: 44,
    height: 44,
    padding: 4,
    borderRadius: 8
  },
  emoji: {
    width: '100%',
    height: '100%'
  }
});
var _default = exports.default = BottomSheetReactionAddon;
//# sourceMappingURL=BottomSheetReactionAddon.js.map