"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _uikitReactNativeFoundation = require("@sendbird/uikit-react-native-foundation");
var _uikitUtils = require("@sendbird/uikit-utils");
var _constants = require("../../constants");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const NUM_COLUMN = 6;
const ReactionListBottomSheet = ({
  visible,
  onClose,
  onDismiss,
  reactionCtx,
  chatCtx
}) => {
  const {
    width
  } = (0, _reactNative.useWindowDimensions)();
  const safeArea = (0, _uikitUtils.useSafeAreaPadding)(['bottom', 'left', 'right']);
  const {
    colors
  } = (0, _uikitReactNativeFoundation.useUIKitTheme)();
  const {
    currentUser,
    emojiManager
  } = chatCtx;
  const {
    channel,
    message
  } = reactionCtx;
  const color = colors.ui.reaction.default;
  return /*#__PURE__*/_react.default.createElement(_uikitReactNativeFoundation.Modal, {
    type: 'slide',
    visible: Boolean(visible && channel && message),
    onClose: onClose,
    onDismiss: onDismiss,
    backgroundStyle: styles.modal
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.container, {
      width,
      paddingBottom: safeArea.paddingBottom,
      backgroundColor: colors.ui.dialog.default.none.background,
      paddingStart: safeArea.paddingStart + styles.container.paddingHorizontal,
      paddingEnd: safeArea.paddingEnd + styles.container.paddingHorizontal
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.FlatList, {
    data: emojiManager.allEmoji,
    numColumns: NUM_COLUMN,
    keyExtractor: item => item.key,
    contentContainerStyle: styles.flatlist,
    ItemSeparatorComponent: () => /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: {
        height: 16
      }
    }),
    renderItem: ({
      item: {
        key,
        url
      }
    }) => {
      var _message$reactions;
      const reactedUserIds = (message === null || message === void 0 || (_message$reactions = message.reactions) === null || _message$reactions === void 0 || (_message$reactions = _message$reactions.find(it => it.key === key)) === null || _message$reactions === void 0 ? void 0 : _message$reactions.userIds) ?? [];
      const idx = reactedUserIds.indexOf((currentUser === null || currentUser === void 0 ? void 0 : currentUser.userId) ?? _constants.UNKNOWN_USER_ID);
      const reacted = idx > -1;
      return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
        style: styles.emojiItem
      }, /*#__PURE__*/_react.default.createElement(_reactNative.Pressable, {
        key: key,
        onPress: async () => {
          if (message && channel) {
            const action = (message, key) => {
              return reacted ? channel.deleteReaction(message, key) : channel.addReaction(message, key);
            };
            action(message, key).catch(error => {
              _uikitUtils.Logger.warn('Failed to reaction', error);
            });
          }
          await onClose();
        },
        style: ({
          pressed
        }) => [styles.button, {
          backgroundColor: reacted || pressed ? color.selected.background : color.enabled.background
        }]
      }, /*#__PURE__*/_react.default.createElement(_uikitReactNativeFoundation.Image, {
        source: {
          uri: url
        },
        style: styles.emoji
      })));
    }
  })));
};
const styles = (0, _uikitReactNativeFoundation.createStyleSheet)({
  container: {
    overflow: 'hidden',
    borderTopStartRadius: 8,
    borderTopEndRadius: 8,
    paddingTop: 16,
    paddingHorizontal: 18,
    flexDirection: 'row'
  },
  modal: {
    alignItems: 'center',
    justifyContent: 'flex-end'
  },
  flatlist: {
    width: '100%',
    flexDirection: 'column',
    justifyContent: 'space-between'
  },
  emojiItem: {
    width: `${100 / NUM_COLUMN}%`,
    alignItems: 'center'
  },
  button: {
    width: 44,
    height: 44,
    padding: 4,
    borderRadius: 8
  },
  emoji: {
    width: '100%',
    height: '100%'
  }
});
var _default = exports.default = ReactionListBottomSheet;
//# sourceMappingURL=ReactionListBottomSheet.js.map