"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ReactionProvider = exports.ReactionContext = void 0;
var _react = _interopRequireWildcard(require("react"));
var _uikitUtils = require("@sendbird/uikit-utils");
var _ReactionBottomSheets = require("../components/ReactionBottomSheets");
var _LocalizationCtx = require("../contexts/LocalizationCtx");
var _SendbirdChatCtx = require("../contexts/SendbirdChatCtx");
var _UserProfileCtx = require("../contexts/UserProfileCtx");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } return n; }, _extends.apply(null, arguments); }
const ReactionContext = exports.ReactionContext = /*#__PURE__*/_react.default.createContext(null);
const ReactionProvider = ({
  children,
  onPressUserProfile
}) => {
  const chatCtx = (0, _react.useContext)(_SendbirdChatCtx.SendbirdChatContext);
  const localizationCtx = (0, _react.useContext)(_LocalizationCtx.LocalizationContext);
  const userProfileCtx = (0, _react.useContext)(_UserProfileCtx.UserProfileContext);
  if (!chatCtx) throw new Error('SendbirdChatContext is not provided');
  if (!localizationCtx) throw new Error('LocalizationContext is not provided');
  if (!userProfileCtx) throw new Error('UserProfileContext is not provided');
  const [state, setState] = (0, _react.useReducer)((prev, next) => ({
    ...prev,
    ...next
  }), {});
  const [reactionListVisible, setReactionListVisible] = (0, _react.useState)(false);
  const [reactionUserListVisible, setReactionUserListVisible] = (0, _react.useState)(false);
  const [reactionUserListFocusIndex, setReactionUserListFocusIndex] = (0, _react.useState)(0);
  const closeResolver = (0, _react.useRef)(_uikitUtils.NOOP);
  const openReactionList = (0, _react.useCallback)(params => {
    setState(params);
    setReactionListVisible(true);
  }, []);
  const openReactionUserList = (0, _react.useCallback)(({
    channel,
    message,
    focusIndex = 0
  }) => {
    setState({
      channel,
      message
    });
    setReactionUserListFocusIndex(focusIndex);
    setReactionUserListVisible(true);
  }, []);
  const updateReactionFocusedItem = (0, _react.useCallback)(params => {
    if (params) setState(params);else setState({});
  }, []);
  const createOnCloseWithResolver = callback => {
    return () => {
      return new Promise(resolve => {
        closeResolver.current = resolve;
        callback();
      });
    };
  };
  const reactionCtx = {
    ...state,
    openReactionList,
    openReactionUserList,
    updateReactionFocusedItem,
    focusIndex: reactionUserListFocusIndex
  };
  const sheetProps = {
    chatCtx,
    reactionCtx,
    localizationCtx,
    onPressUserProfile: onPressUserProfile ?? userProfileCtx.show,
    onDismiss: () => {
      var _closeResolver$curren;
      setState({});
      (_closeResolver$curren = closeResolver.current) === null || _closeResolver$curren === void 0 || _closeResolver$curren.call(closeResolver);
    }
  };
  return /*#__PURE__*/_react.default.createElement(ReactionContext.Provider, {
    value: reactionCtx
  }, children, /*#__PURE__*/_react.default.createElement(_ReactionBottomSheets.ReactionBottomSheets.UserList, _extends({}, sheetProps, {
    visible: reactionUserListVisible,
    onClose: createOnCloseWithResolver(() => setReactionUserListVisible(false))
  })), /*#__PURE__*/_react.default.createElement(_ReactionBottomSheets.ReactionBottomSheets.ReactionList, _extends({}, sheetProps, {
    visible: reactionListVisible,
    onClose: createOnCloseWithResolver(() => setReactionListVisible(false))
  })));
};
exports.ReactionProvider = ReactionProvider;
//# sourceMappingURL=ReactionCtx.js.map