"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SendbirdChatProvider = exports.SendbirdChatContext = void 0;
var _react = _interopRequireWildcard(require("react"));
var _uikitChatHooks = require("@sendbird/uikit-chat-hooks");
var _uikitTools = require("@sendbird/uikit-tools");
var _uikitUtils = require("@sendbird/uikit-utils");
var _pubsub = _interopRequireDefault(require("../utils/pubsub"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const SendbirdChatContext = exports.SendbirdChatContext = /*#__PURE__*/_react.default.createContext(null);
const SendbirdChatProvider = ({
  children,
  sdkInstance,
  emojiManager,
  mentionManager,
  voiceMessageStatusManager,
  imageCompressionConfig,
  voiceMessageConfig,
  enableAutoPushTokenRegistration,
  enableUseUserIdForNickname,
  enableImageCompression
}) => {
  const [currentUser, _setCurrentUser] = (0, _react.useState)();
  const forceUpdate = (0, _uikitUtils.useForceUpdate)();
  const appFeatures = (0, _uikitChatHooks.useAppFeatures)(sdkInstance);
  const {
    configs,
    configsWithAppAttr
  } = (0, _uikitTools.useUIKitConfig)();
  const setCurrentUser = (0, _react.useCallback)(user => {
    // NOTE: Sendbird SDK handle User object is always same object, so force update after setCurrentUser
    _setCurrentUser(user);
    forceUpdate();
  }, []);
  const updateCurrentUserInfo = (0, _react.useCallback)(async (nickname, profile) => {
    let user = currentUser;
    if (!user) throw new Error('Current user is not defined, please connect using `useConnection()` hook first');
    const params = {};
    if (!nickname) {
      params.nickname = user.nickname;
    } else {
      params.nickname = nickname;
    }
    if (!profile) {
      params.profileUrl = user.profileUrl;
    } else if (typeof profile === 'string') {
      params.profileUrl = profile;
    } else if (typeof profile === 'object') {
      params.profileImage = profile;
    } else {
      throw new Error(`Cannot update profile, not supported profile type(${typeof profile})`);
    }
    user = await sdkInstance.updateCurrentUserInfo(params);
    setCurrentUser(user);
    return user;
  }, [sdkInstance, currentUser, setCurrentUser]);
  const markAsDeliveredWithChannel = (0, _react.useCallback)(channel => {
    if (appFeatures.deliveryReceiptEnabled) (0, _uikitUtils.confirmAndMarkAsDelivered)([channel]);
  }, [sdkInstance, appFeatures.deliveryReceiptEnabled]);
  (0, _uikitUtils.useAppState)('change', status => {
    // 'active' | 'background' | 'inactive' | 'unknown' | 'extension';
    if (status === 'active') sdkInstance.connectionState === 'CLOSED' && sdkInstance.setForegroundState();else if (status === 'background') sdkInstance.connectionState === 'OPEN' && sdkInstance.setBackgroundState();
  });
  (0, _react.useEffect)(() => {
    return () => {
      sdkInstance.disconnectWebSocket().then(() => _setCurrentUser(undefined));
    };
  }, [sdkInstance]);
  const value = {
    sdk: sdkInstance,
    emojiManager,
    mentionManager,
    imageCompressionConfig,
    voiceMessageConfig,
    voiceMessageStatusManager,
    currentUser,
    setCurrentUser,
    updateCurrentUserInfo,
    markAsDeliveredWithChannel,
    groupChannelFragmentOptions: {
      pubsub: (0, _pubsub.default)()
    },
    // TODO: Options should be moved to the common area at the higher level to be passed to the context of each product.
    //  For example, common -> chat context, common -> calls context
    sbOptions: {
      appInfo: appFeatures,
      uikit: configs,
      uikitWithAppInfo: configsWithAppAttr(sdkInstance),
      chat: {
        autoPushTokenRegistrationEnabled: enableAutoPushTokenRegistration,
        useUserIdForNicknameEnabled: enableUseUserIdForNickname,
        imageCompressionEnabled: enableImageCompression
      }
    }
  };
  return /*#__PURE__*/_react.default.createElement(SendbirdChatContext.Provider, {
    value: value
  }, children);
};
exports.SendbirdChatProvider = SendbirdChatProvider;
//# sourceMappingURL=SendbirdChatCtx.js.map