"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GroupChannelContextsProvider = exports.GroupChannelContexts = void 0;
var _react = _interopRequireWildcard(require("react"));
var _uikitTools = require("@sendbird/uikit-tools");
var _uikitUtils = require("@sendbird/uikit-utils");
var _ProviderLayout = _interopRequireDefault(require("../../../components/ProviderLayout"));
var _constants = require("../../../constants");
var _useContext = require("../../../hooks/useContext");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const GroupChannelContexts = exports.GroupChannelContexts = {
  Fragment: /*#__PURE__*/(0, _react.createContext)({
    headerTitle: '',
    channel: {},
    setMessageToEdit: _uikitUtils.NOOP,
    setMessageToReply: _uikitUtils.NOOP
  }),
  TypingIndicator: /*#__PURE__*/(0, _react.createContext)({
    typingUsers: []
  }),
  PubSub: /*#__PURE__*/(0, _react.createContext)({
    publish: _uikitUtils.NOOP,
    subscribe: () => _uikitUtils.NOOP
  }),
  MessageList: /*#__PURE__*/(0, _react.createContext)({
    flatListRef: {
      current: null
    },
    scrollToMessage: () => false,
    lazyScrollToBottom: () => {
      // noop
    },
    lazyScrollToIndex: () => {
      // noop
    }
  })
};
const GroupChannelContextsProvider = ({
  children,
  channel,
  enableTypingIndicator,
  keyboardAvoidOffset = 0,
  groupChannelPubSub,
  messages,
  onUpdateSearchItem,
  onPressReplyMessageInThread
}) => {
  if (!channel) throw new Error('GroupChannel is not provided to GroupChannelModule');
  const {
    STRINGS
  } = (0, _useContext.useLocalization)();
  const {
    currentUser,
    sdk,
    sbOptions
  } = (0, _useContext.useSendbirdChat)();
  const [typingUsers, setTypingUsers] = (0, _react.useState)([]);
  const [messageToEdit, setMessageToEdit] = (0, _react.useState)();
  const [messageToReply, setMessageToReply] = (0, _react.useState)();
  const {
    flatListRef,
    lazyScrollToIndex,
    lazyScrollToBottom,
    scrollToMessage
  } = useScrollActions({
    messages,
    onUpdateSearchItem
  });
  const updateInputMode = (mode, message) => {
    if (mode === 'send' || !message) {
      setMessageToEdit(undefined);
      setMessageToReply(undefined);
      return;
    } else if (mode === 'edit') {
      setMessageToEdit(message);
      setMessageToReply(undefined);
      return;
    } else if (mode === 'reply') {
      setMessageToEdit(undefined);
      setMessageToReply(message);
      return;
    }
  };
  const onPressMessageToReply = parentMessage => {
    if (sbOptions.uikit.groupChannel.channel.replyType === 'thread' && parentMessage) {
      onPressReplyMessageInThread === null || onPressReplyMessageInThread === void 0 || onPressReplyMessageInThread(parentMessage, Number.MAX_SAFE_INTEGER);
    } else if (sbOptions.uikit.groupChannel.channel.replyType === 'quote_reply') {
      updateInputMode('reply', parentMessage);
    }
  };
  (0, _uikitTools.useGroupChannelHandler)(sdk, {
    onMessageDeleted(_, messageId) {
      if ((messageToReply === null || messageToReply === void 0 ? void 0 : messageToReply.messageId) === messageId) {
        setMessageToReply(undefined);
      }
    },
    onChannelFrozen(frozenChannel) {
      if (frozenChannel.url === channel.url) {
        if (frozenChannel.isGroupChannel() && (0, _uikitUtils.getGroupChannelChatAvailableState)(channel).frozen) {
          setMessageToReply(undefined);
        }
      }
    },
    onUserMuted(mutedChannel, user) {
      var _sdk$currentUser;
      if (mutedChannel.url === channel.url && user.userId === ((_sdk$currentUser = sdk.currentUser) === null || _sdk$currentUser === void 0 ? void 0 : _sdk$currentUser.userId)) {
        setMessageToReply(undefined);
      }
    },
    onTypingStatusUpdated(eventChannel) {
      if ((0, _uikitUtils.isDifferentChannel)(channel, eventChannel)) return;
      if (!enableTypingIndicator) return;
      setTypingUsers(eventChannel.getTypingUsers());
    }
  });
  return /*#__PURE__*/_react.default.createElement(_ProviderLayout.default, null, /*#__PURE__*/_react.default.createElement(GroupChannelContexts.Fragment.Provider, {
    value: {
      headerTitle: STRINGS.GROUP_CHANNEL.HEADER_TITLE((currentUser === null || currentUser === void 0 ? void 0 : currentUser.userId) ?? '', channel),
      channel,
      keyboardAvoidOffset,
      messageToEdit,
      setMessageToEdit: (0, _react.useCallback)(message => updateInputMode('edit', message), []),
      messageToReply,
      setMessageToReply: (0, _react.useCallback)(message => onPressMessageToReply(message), [])
    }
  }, /*#__PURE__*/_react.default.createElement(GroupChannelContexts.PubSub.Provider, {
    value: groupChannelPubSub
  }, /*#__PURE__*/_react.default.createElement(GroupChannelContexts.TypingIndicator.Provider, {
    value: {
      typingUsers
    }
  }, /*#__PURE__*/_react.default.createElement(GroupChannelContexts.MessageList.Provider, {
    value: {
      flatListRef,
      scrollToMessage,
      lazyScrollToIndex,
      lazyScrollToBottom,
      onPressReplyMessageInThread
    }
  }, children)))));
};
exports.GroupChannelContextsProvider = GroupChannelContextsProvider;
const useScrollActions = params => {
  const {
    messages,
    onUpdateSearchItem
  } = params;
  const flatListRef = (0, _react.useRef)(null);

  // FIXME: Workaround, should run after data has been applied to UI.
  const lazyScrollToBottom = (0, _uikitUtils.useFreshCallback)(params => {
    if (!flatListRef.current) {
      logFlatListRefWarning();
      return;
    }
    setTimeout(() => {
      var _flatListRef$current;
      (_flatListRef$current = flatListRef.current) === null || _flatListRef$current === void 0 || _flatListRef$current.scrollToOffset({
        offset: 0,
        animated: (params === null || params === void 0 ? void 0 : params.animated) ?? false
      });
    }, (params === null || params === void 0 ? void 0 : params.timeout) ?? 0);
  });

  // FIXME: Workaround, should run after data has been applied to UI.
  const lazyScrollToIndex = (0, _uikitUtils.useFreshCallback)(params => {
    if (!flatListRef.current) {
      logFlatListRefWarning();
      return;
    }
    setTimeout(() => {
      var _flatListRef$current2;
      (_flatListRef$current2 = flatListRef.current) === null || _flatListRef$current2 === void 0 || _flatListRef$current2.scrollToIndex({
        index: (params === null || params === void 0 ? void 0 : params.index) ?? 0,
        animated: (params === null || params === void 0 ? void 0 : params.animated) ?? false,
        viewPosition: (params === null || params === void 0 ? void 0 : params.viewPosition) ?? 0.5
      });
    }, (params === null || params === void 0 ? void 0 : params.timeout) ?? 0);
  });
  const scrollToMessage = (0, _uikitUtils.useFreshCallback)((messageId, options) => {
    if (!flatListRef.current) {
      logFlatListRefWarning();
      return false;
    }
    const foundMessageIndex = messages.findIndex(it => it.messageId === messageId);
    const isIncludedInList = foundMessageIndex > -1;
    if (isIncludedInList) {
      if (options !== null && options !== void 0 && options.focusAnimated) {
        setTimeout(() => onUpdateSearchItem({
          startingPoint: messages[foundMessageIndex].createdAt
        }), _constants.MESSAGE_FOCUS_ANIMATION_DELAY);
      }
      lazyScrollToIndex({
        index: foundMessageIndex,
        animated: true,
        timeout: 0,
        viewPosition: options === null || options === void 0 ? void 0 : options.viewPosition
      });
      return true;
    } else {
      return false;
    }
  });
  return {
    flatListRef,
    lazyScrollToIndex,
    lazyScrollToBottom,
    scrollToMessage
  };
};
const logFlatListRefWarning = () => {
  _uikitUtils.Logger.warn('Cannot find flatListRef.current, please render FlatList and pass the flatListRef' + 'or please try again after FlatList has been rendered.');
};
//# sourceMappingURL=moduleContext.js.map