"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _uikitReactNativeFoundation = require("@sendbird/uikit-react-native-foundation");
var _useContext = require("../../../hooks/useContext");
var _moduleContext = require("../module/moduleContext");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const TYPES = ['GROUP', 'SUPER_GROUP', 'BROADCAST'];
const TYPE_ICONS = {
  'GROUP': 'chat',
  'SUPER_GROUP': 'supergroup',
  'BROADCAST': 'broadcast'
};
const STATUS_BAR_TOP_INSET_AS = _reactNative.Platform.select({
  android: 'margin',
  default: 'padding'
});
const GroupChannelListTypeSelector = ({
  skipTypeSelection,
  onSelectType
}) => {
  const {
    statusBarTranslucent,
    HeaderComponent
  } = (0, _uikitReactNativeFoundation.useHeaderStyle)();
  const {
    colors
  } = (0, _uikitReactNativeFoundation.useUIKitTheme)();
  const {
    sbOptions
  } = (0, _useContext.useSendbirdChat)();
  const typeSelector = (0, _react.useContext)(_moduleContext.GroupChannelListContexts.TypeSelector);
  const {
    visible,
    hide
  } = typeSelector;
  const createOnPressType = type => () => {
    hide();
    onSelectType(type);
  };
  (0, _react.useEffect)(() => {
    if (skipTypeSelection && visible) createOnPressType('GROUP')();
  }, [skipTypeSelection, visible]);
  if (skipTypeSelection) return null;
  return /*#__PURE__*/_react.default.createElement(_uikitReactNativeFoundation.Modal, {
    visible: visible,
    onClose: hide,
    statusBarTranslucent: statusBarTranslucent
  }, /*#__PURE__*/_react.default.createElement(HeaderComponent, {
    title: typeSelector.headerTitle,
    right: /*#__PURE__*/_react.default.createElement(_uikitReactNativeFoundation.Icon, {
      icon: 'close',
      color: colors.onBackground01
    }),
    onPressRight: typeSelector.hide,
    statusBarTopInsetAs: STATUS_BAR_TOP_INSET_AS
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.buttonArea
  }, TYPES.map(type => {
    if (type === 'SUPER_GROUP' && !sbOptions.appInfo.superGroupChannelEnabled) {
      return null;
    }
    if (type === 'BROADCAST' && !sbOptions.appInfo.broadcastChannelEnabled) {
      return null;
    }
    return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      key: type,
      activeOpacity: 0.6,
      onPress: createOnPressType(type),
      style: styles.typeButton
    }, /*#__PURE__*/_react.default.createElement(DefaultTypeIcon, {
      type: type
    }), /*#__PURE__*/_react.default.createElement(DefaultTypeText, {
      type: type
    }));
  }))));
};
const DefaultTypeIcon = ({
  type
}) => {
  return /*#__PURE__*/_react.default.createElement(_uikitReactNativeFoundation.Icon, {
    size: 24,
    icon: TYPE_ICONS[type],
    containerStyle: styles.icon
  });
};
const DefaultTypeText = ({
  type
}) => {
  const {
    STRINGS
  } = (0, _useContext.useLocalization)();
  const {
    colors
  } = (0, _uikitReactNativeFoundation.useUIKitTheme)();
  return /*#__PURE__*/_react.default.createElement(_uikitReactNativeFoundation.Text, {
    caption2: true,
    color: colors.onBackground01
  }, STRINGS.GROUP_CHANNEL_LIST[`TYPE_SELECTOR_${type}`]);
};
const styles = (0, _uikitReactNativeFoundation.createStyleSheet)({
  buttonArea: {
    flexDirection: 'row'
  },
  typeButton: {
    paddingVertical: 24,
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center'
  },
  icon: {
    marginBottom: 8
  }
});
var _default = exports.default = GroupChannelListTypeSelector;
//# sourceMappingURL=GroupChannelListTypeSelector.js.map