"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _uikitTools = require("@sendbird/uikit-tools");
var _uikitUtils = require("@sendbird/uikit-utils");
var _ChannelThreadMessageList = _interopRequireDefault(require("../../../components/ChannelThreadMessageList"));
var _useContext = require("../../../hooks/useContext");
var _moduleContext = require("../module/moduleContext");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } return n; }, _extends.apply(null, arguments); }
const GroupChannelThreadMessageList = props => {
  const {
    sdk
  } = (0, _useContext.useSendbirdChat)();
  const {
    setMessageToEdit
  } = (0, _react.useContext)(_moduleContext.GroupChannelThreadContexts.Fragment);
  const {
    subscribe
  } = (0, _react.useContext)(_moduleContext.GroupChannelThreadContexts.PubSub);
  const {
    flatListRef,
    lazyScrollToBottom,
    lazyScrollToIndex
  } = (0, _react.useContext)(_moduleContext.GroupChannelThreadContexts.MessageList);
  const ignorePropReached = (0, _react.useRef)(false);
  const _onTopReached = () => {
    if (!ignorePropReached.current) {
      props.onTopReached();
    }
  };
  const _onBottomReached = () => {
    if (!ignorePropReached.current) {
      props.onBottomReached();
    }
  };
  const scrollToBottom = (0, _uikitUtils.useFreshCallback)(async (animated = false) => {
    if (props.hasNext()) {
      props.onScrolledAwayFromBottom(false);
      await props.onResetMessageList().catch(_ => {});
      props.onScrolledAwayFromBottom(false);
      lazyScrollToBottom({
        animated
      });
    } else {
      lazyScrollToBottom({
        animated
      });
    }
  });
  (0, _react.useLayoutEffect)(() => {
    if (props.startingPoint) {
      const foundMessageIndex = props.messages.findIndex(it => it.createdAt === props.startingPoint);
      const isIncludedInList = foundMessageIndex > -1;
      if (isIncludedInList) {
        ignorePropReached.current = true;
        const timeout = 300;
        lazyScrollToIndex({
          index: foundMessageIndex,
          animated: true,
          timeout: timeout
        });
        setTimeout(() => {
          ignorePropReached.current = false;
        }, timeout + 50);
      }
    }
  }, [props.startingPoint]);
  (0, _uikitTools.useGroupChannelHandler)(sdk, {
    onReactionUpdated(channel, event) {
      if ((0, _uikitUtils.isDifferentChannel)(channel, props.channel)) return;
      const recentMessage = props.messages[0];
      const isRecentMessage = recentMessage && recentMessage.messageId === event.messageId;
      const scrollReachedBottomAndCanScroll = !props.scrolledAwayFromBottom && !props.hasNext();
      if (isRecentMessage && scrollReachedBottomAndCanScroll) {
        lazyScrollToBottom({
          animated: true,
          timeout: 250
        });
      }
    }
  });
  (0, _react.useEffect)(() => {
    return subscribe(({
      type,
      data
    }) => {
      switch (type) {
        case 'TYPING_BUBBLE_RENDERED':
        case 'MESSAGES_RECEIVED':
          {
            if (!props.scrolledAwayFromBottom) {
              scrollToBottom(true);
            }
            break;
          }
        case 'MESSAGES_UPDATED':
          {
            const lastMessage = props.channel.lastMessage;
            const [updatedMessage] = data.messages;
            const lastMessageUpdated = updatedMessage && lastMessage && lastMessage.messageId === updatedMessage.messageId;
            const isMaybeStreaming = props.channel.hasAiBot && lastMessageUpdated;
            if (isMaybeStreaming) {
              scrollToBottom(false);
            } else if (!props.scrolledAwayFromBottom && lastMessageUpdated) {
              scrollToBottom(true);
            }
            break;
          }
        case 'MESSAGE_SENT_SUCCESS':
        case 'MESSAGE_SENT_PENDING':
          {
            scrollToBottom(false);
            break;
          }
      }
    });
  }, [props.scrolledAwayFromBottom]);
  return /*#__PURE__*/_react.default.createElement(_ChannelThreadMessageList.default, _extends({}, props, {
    ref: flatListRef,
    onTopReached: _onTopReached,
    onBottomReached: _onBottomReached,
    onEditMessage: setMessageToEdit,
    onPressNewMessagesButton: scrollToBottom,
    onPressScrollToBottomButton: scrollToBottom,
    renderNewMessagesButton: null,
    renderScrollToBottomButton: null
  }));
};
var _default = exports.default = /*#__PURE__*/_react.default.memo(GroupChannelThreadMessageList);
//# sourceMappingURL=GroupChannelThreadMessageList.js.map