"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _groupChannel = require("@sendbird/chat/groupChannel");
var _message = require("@sendbird/chat/message");
var _uikitReactNativeFoundation = require("@sendbird/uikit-react-native-foundation");
var _uikitTools = require("@sendbird/uikit-tools");
var _uikitUtils = require("@sendbird/uikit-utils");
var _GroupChannelMessageRenderer = _interopRequireWildcard(require("../components/GroupChannelMessageRenderer"));
var _NewMessagesButton = _interopRequireDefault(require("../components/NewMessagesButton"));
var _ScrollToBottomButton = _interopRequireDefault(require("../components/ScrollToBottomButton"));
var _StatusComposition = _interopRequireDefault(require("../components/StatusComposition"));
var _createGroupChannelModule = _interopRequireDefault(require("../domain/groupChannel/module/createGroupChannelModule"));
var _useContext = require("../hooks/useContext");
var _pubsub = _interopRequireDefault(require("../utils/pubsub"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const createGroupChannelFragment = initModule => {
  const GroupChannelModule = (0, _createGroupChannelModule.default)(initModule);
  return ({
    searchItem,
    renderNewMessagesButton = props => /*#__PURE__*/_react.default.createElement(_NewMessagesButton.default, props),
    renderScrollToBottomButton = props => /*#__PURE__*/_react.default.createElement(_ScrollToBottomButton.default, props),
    renderMessage,
    enableMessageGrouping = true,
    enableTypingIndicator,
    onPressHeaderLeft = _uikitUtils.NOOP,
    onPressHeaderRight = _uikitUtils.NOOP,
    onPressMediaMessage = _uikitUtils.NOOP,
    onChannelDeleted = _uikitUtils.NOOP,
    onPressReplyMessageInThread = _uikitUtils.NOOP,
    onBeforeSendUserMessage = _uikitUtils.PASS,
    onBeforeSendFileMessage = _uikitUtils.PASS,
    onBeforeUpdateUserMessage = _uikitUtils.PASS,
    onBeforeUpdateFileMessage = _uikitUtils.PASS,
    channel,
    keyboardAvoidOffset,
    sortComparator = _uikitUtils.messageComparator,
    flatListComponent,
    flatListProps,
    messageListQueryParams,
    collectionCreator
  }) => {
    const {
      playerService,
      recorderService
    } = (0, _useContext.usePlatformService)();
    const {
      sdk,
      currentUser,
      sbOptions,
      voiceMessageStatusManager
    } = (0, _useContext.useSendbirdChat)();
    const toast = (0, _uikitReactNativeFoundation.useToast)();
    const {
      STRINGS
    } = (0, _useContext.useLocalization)();
    const [internalSearchItem, setInternalSearchItem] = (0, _react.useState)(searchItem);
    const navigateFromMessageSearch = (0, _react.useCallback)(() => Boolean(searchItem), []);
    const [groupChannelPubSub] = (0, _react.useState)(() => (0, _pubsub.default)());
    const [scrolledAwayFromBottom, setScrolledAwayFromBottom] = (0, _react.useState)(false);
    const scrolledAwayFromBottomRef = (0, _uikitUtils.useRefTracker)(scrolledAwayFromBottom);
    const replyType = (0, _uikitUtils.useIIFE)(() => {
      if (sbOptions.uikit.groupChannel.channel.replyType === 'none') {
        return _message.ReplyType.NONE;
      } else {
        return _message.ReplyType.ONLY_REPLY_TO_CHANNEL;
      }
    });
    const {
      loading,
      messages,
      newMessages,
      resetNewMessages,
      loadNext,
      loadPrevious,
      hasNext,
      sendFileMessage,
      sendUserMessage,
      updateFileMessage,
      updateUserMessage,
      resendMessage,
      deleteMessage,
      resetWithStartingPoint
    } = (0, _uikitTools.useGroupChannelMessages)(sdk, channel, {
      shouldCountNewMessages: () => scrolledAwayFromBottomRef.current,
      onMessagesReceived(messages) {
        groupChannelPubSub.publish({
          type: 'MESSAGES_RECEIVED',
          data: {
            messages
          }
        });
      },
      onMessagesUpdated(messages) {
        groupChannelPubSub.publish({
          type: 'MESSAGES_UPDATED',
          data: {
            messages
          }
        });
      },
      onChannelDeleted,
      onCurrentUserBanned: onChannelDeleted,
      collectionCreator: getCollectionCreator(channel, messageListQueryParams, collectionCreator),
      sortComparator,
      markAsRead: _uikitUtils.confirmAndMarkAsRead,
      replyType,
      startingPoint: internalSearchItem === null || internalSearchItem === void 0 ? void 0 : internalSearchItem.startingPoint
    });
    const onBlurFragment = async () => {
      await playerService.reset().catch(() => {});
      await recorderService.reset().catch(() => {});
    };
    const _onPressHeaderLeft = (0, _uikitUtils.useFreshCallback)(async () => {
      await onBlurFragment();
      onPressHeaderLeft();
    });
    const _onPressHeaderRight = (0, _uikitUtils.useFreshCallback)(async () => {
      await onBlurFragment();
      onPressHeaderRight();
    });
    const _onPressMediaMessage = (0, _uikitUtils.useFreshCallback)(async (message, deleteMessage, uri) => {
      await onBlurFragment();
      onPressMediaMessage(message, deleteMessage, uri);
    });
    const _onPressReplyMessageInThread = (0, _uikitUtils.useFreshCallback)(async (message, startingPoint) => {
      await onBlurFragment();
      onPressReplyMessageInThread(message, startingPoint);
    });
    (0, _react.useEffect)(() => {
      return () => {
        voiceMessageStatusManager.clear();
        onBlurFragment();
      };
    }, []);
    const renderItem = (0, _uikitUtils.useFreshCallback)(props => {
      const content = renderMessage ? renderMessage(props) : /*#__PURE__*/_react.default.createElement(_GroupChannelMessageRenderer.default, props);
      return /*#__PURE__*/_react.default.createElement(_uikitReactNativeFoundation.Box, null, content, props.isFirstItem && !hasNext() && /*#__PURE__*/_react.default.createElement(_GroupChannelMessageRenderer.GroupChannelTypingIndicatorBubble, null));
    });
    const memoizedFlatListProps = (0, _react.useMemo)(() => ({
      ListEmptyComponent: /*#__PURE__*/_react.default.createElement(GroupChannelModule.StatusEmpty, null),
      contentContainerStyle: {
        flexGrow: 1
      },
      ...flatListProps
    }), [flatListProps]);
    const onResetMessageList = (0, _react.useCallback)(async () => {
      return await resetWithStartingPoint(Number.MAX_SAFE_INTEGER);
    }, []);
    const onResetMessageListWithStartingPoint = (0, _react.useCallback)(async startingPoint => {
      return await resetWithStartingPoint(startingPoint);
    }, []);

    // Changing the search item will trigger the focus animation on messages.
    const onUpdateSearchItem = (0, _react.useCallback)(searchItem => {
      // Clean up for animation trigger with useEffect
      setInternalSearchItem(undefined);
      setInternalSearchItem(searchItem);
    }, []);
    const onPending = message => {
      groupChannelPubSub.publish({
        type: 'MESSAGE_SENT_PENDING',
        data: {
          message
        }
      });
    };
    const onSent = message => {
      groupChannelPubSub.publish({
        type: 'MESSAGE_SENT_SUCCESS',
        data: {
          message
        }
      });
    };
    const onPressSendUserMessage = (0, _uikitUtils.useFreshCallback)(async params => {
      const processedParams = await onBeforeSendUserMessage(params);
      const message = await sendUserMessage(processedParams, onPending);
      onSent(message);
    });
    const onPressSendFileMessage = (0, _uikitUtils.useFreshCallback)(async params => {
      var _processedParams$file;
      const processedParams = await onBeforeSendFileMessage(params);
      const fileSize = ((_processedParams$file = processedParams.file) === null || _processedParams$file === void 0 ? void 0 : _processedParams$file.size) ?? processedParams.fileSize;
      const uploadSizeLimit = sbOptions.appInfo.uploadSizeLimit;
      if (fileSize && uploadSizeLimit && fileSize > uploadSizeLimit) {
        const sizeLimitString = `${(0, _uikitUtils.getReadableFileSize)(uploadSizeLimit)}`;
        toast.show(STRINGS.TOAST.FILE_UPLOAD_SIZE_LIMIT_EXCEEDED_ERROR(sizeLimitString), 'error');
        return;
      } else {
        const message = await sendFileMessage(processedParams, onPending);
        onSent(message);
      }
    });
    const onPressUpdateUserMessage = (0, _uikitUtils.useFreshCallback)(async (message, params) => {
      const processedParams = await onBeforeUpdateUserMessage(params);
      await updateUserMessage(message.messageId, processedParams);
    });
    const onPressUpdateFileMessage = (0, _uikitUtils.useFreshCallback)(async (message, params) => {
      const processedParams = await onBeforeUpdateFileMessage(params);
      await updateFileMessage(message.messageId, processedParams);
    });
    const onScrolledAwayFromBottom = (0, _uikitUtils.useFreshCallback)(value => {
      if (!value) resetNewMessages();
      setScrolledAwayFromBottom(value);
    });
    return /*#__PURE__*/_react.default.createElement(GroupChannelModule.Provider, {
      channel: channel,
      groupChannelPubSub: groupChannelPubSub,
      enableTypingIndicator: enableTypingIndicator ?? sbOptions.uikit.groupChannel.channel.enableTypingIndicator,
      keyboardAvoidOffset: keyboardAvoidOffset,
      messages: messages,
      onUpdateSearchItem: onUpdateSearchItem,
      onPressReplyMessageInThread: _onPressReplyMessageInThread
    }, /*#__PURE__*/_react.default.createElement(GroupChannelModule.Header, {
      shouldHideRight: navigateFromMessageSearch,
      onPressHeaderLeft: _onPressHeaderLeft,
      onPressHeaderRight: _onPressHeaderRight
    }), /*#__PURE__*/_react.default.createElement(_StatusComposition.default, {
      loading: loading,
      LoadingComponent: /*#__PURE__*/_react.default.createElement(GroupChannelModule.StatusLoading, null)
    }, /*#__PURE__*/_react.default.createElement(GroupChannelModule.MessageList, {
      channel: channel,
      searchItem: internalSearchItem,
      onResetMessageList: onResetMessageList,
      onResetMessageListWithStartingPoint: onResetMessageListWithStartingPoint,
      onUpdateSearchItem: onUpdateSearchItem,
      enableMessageGrouping: enableMessageGrouping,
      currentUserId: currentUser === null || currentUser === void 0 ? void 0 : currentUser.userId,
      renderMessage: renderItem,
      messages: messages,
      newMessages: newMessages,
      onTopReached: loadPrevious,
      onBottomReached: loadNext,
      hasNext: hasNext,
      scrolledAwayFromBottom: scrolledAwayFromBottom,
      onScrolledAwayFromBottom: onScrolledAwayFromBottom,
      renderNewMessagesButton: renderNewMessagesButton,
      renderScrollToBottomButton: renderScrollToBottomButton,
      onResendFailedMessage: resendMessage,
      onDeleteMessage: deleteMessage,
      onPressMediaMessage: _onPressMediaMessage,
      flatListComponent: flatListComponent,
      flatListProps: memoizedFlatListProps
    }), /*#__PURE__*/_react.default.createElement(GroupChannelModule.Input, {
      SuggestedMentionList: GroupChannelModule.SuggestedMentionList,
      shouldRenderInput: shouldRenderInput(channel),
      onPressSendUserMessage: onPressSendUserMessage,
      onPressSendFileMessage: onPressSendFileMessage,
      onPressUpdateUserMessage: onPressUpdateUserMessage,
      onPressUpdateFileMessage: onPressUpdateFileMessage
    })));
  };
};
function shouldRenderInput(channel) {
  if (channel.isBroadcast) {
    return channel.myRole === 'operator';
  }
  return true;
}
function getCollectionCreator(channel, messageListQueryParams, deprecatedCreatorProp) {
  if (!messageListQueryParams && deprecatedCreatorProp) return deprecatedCreatorProp;
  return defaultParams => {
    const params = {
      ...defaultParams,
      ...messageListQueryParams
    };
    return channel.createMessageCollection({
      ...params,
      filter: new _groupChannel.MessageFilter(params)
    });
  };
}
var _default = exports.default = createGroupChannelFragment;
//# sourceMappingURL=createGroupChannelFragment.js.map