import React from 'react';
import { Box, Icon, PressBox, Text, createStyleSheet, useHeaderStyle, useUIKitTheme } from '@sendbird/uikit-react-native-foundation';
import { truncate, useSafeAreaPadding } from '@sendbird/uikit-utils';
const FileViewerHeader = ({
  headerShown = true,
  topInset,
  onClose,
  subtitle,
  title
}) => {
  const {
    palette
  } = useUIKitTheme();
  const {
    defaultHeight
  } = useHeaderStyle();
  const safeArea = useSafeAreaPadding(['left', 'right']);
  if (!headerShown) return null;
  return /*#__PURE__*/React.createElement(Box, {
    style: [styles.container, {
      paddingStart: styles.container.paddingHorizontal + safeArea.paddingStart,
      paddingEnd: styles.container.paddingHorizontal + safeArea.paddingEnd,
      paddingTop: topInset,
      height: defaultHeight + topInset,
      backgroundColor: palette.overlay01
    }]
  }, /*#__PURE__*/React.createElement(PressBox, {
    activeOpacity: 0.75,
    onPress: onClose,
    style: styles.buttonContainer
  }, /*#__PURE__*/React.createElement(Icon, {
    icon: 'close',
    size: 24,
    color: palette.onBackgroundDark01
  })), /*#__PURE__*/React.createElement(Box, {
    style: styles.titleContainer
  }, /*#__PURE__*/React.createElement(Text, {
    h2: true,
    color: palette.onBackgroundDark01,
    style: styles.title,
    numberOfLines: 1
  }, truncate(title, {
    mode: 'mid',
    maxLen: 18
  })), /*#__PURE__*/React.createElement(Text, {
    caption2: true,
    color: palette.onBackgroundDark01,
    numberOfLines: 1
  }, subtitle)), /*#__PURE__*/React.createElement(Box, {
    style: styles.buttonContainer
  }));
};
const styles = createStyleSheet({
  container: {
    zIndex: 1,
    top: 0,
    start: 0,
    end: 0,
    position: 'absolute',
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    paddingHorizontal: 12
  },
  buttonContainer: {
    width: 32,
    height: 32,
    alignItems: 'center',
    justifyContent: 'center'
  },
  titleContainer: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center'
  },
  title: {
    marginBottom: 2
  }
});
export default FileViewerHeader;
//# sourceMappingURL=FileViewerHeader.js.map