function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } return n; }, _extends.apply(null, arguments); }
import React, { useRef } from 'react';
import { Text, useUIKitTheme } from '@sendbird/uikit-react-native-foundation';
import { getMessageType, isMyMessage, isVoiceMessage } from '@sendbird/uikit-utils';
import { VOICE_MESSAGE_META_ARRAY_DURATION_KEY } from '../../constants';
import { usePlatformService, useSBUHandlers, useSendbirdChat } from './../../hooks/useContext';
import ThreadParentMessageFile from './ThreadParentMessage.file';
import ThreadParentMessageFileImage from './ThreadParentMessage.file.image';
import ThreadParentMessageFileVideo from './ThreadParentMessage.file.video';
import ThreadParentMessageFileVoice from './ThreadParentMessage.file.voice';
import ThreadParentMessageUser from './ThreadParentMessage.user';
import ThreadParentMessageUserOg from './ThreadParentMessage.user.og';
const ThreadParentMessageRenderer = props => {
  const handlers = useSBUHandlers();
  const playerUnsubscribes = useRef([]);
  const {
    sbOptions,
    currentUser,
    mentionManager,
    voiceMessageStatusManager
  } = useSendbirdChat();
  const {
    palette
  } = useUIKitTheme();
  const {
    mediaService,
    playerService
  } = usePlatformService();
  const parentMessage = props.parentMessage;
  const resetPlayer = async () => {
    playerUnsubscribes.current.forEach(unsubscribe => {
      try {
        unsubscribe();
      } catch {}
    });
    playerUnsubscribes.current.length = 0;
    await playerService.reset();
  };
  const messageProps = {
    onPressURL: url => handlers.onOpenURL(url),
    onToggleVoiceMessage: async (state, setState) => {
      if (isVoiceMessage(parentMessage) && parentMessage.sendingStatus === 'succeeded') {
        if (playerService.uri === parentMessage.url) {
          if (playerService.state === 'playing') {
            await playerService.pause();
          } else {
            await playerService.play(parentMessage.url);
          }
        } else {
          if (playerService.state !== 'idle') {
            await resetPlayer();
          }
          const shouldSeekToTime = state.duration > state.currentTime && state.currentTime > 0;
          let seekFinished = !shouldSeekToTime;
          const forPlayback = playerService.addPlaybackListener(({
            stopped,
            currentTime,
            duration
          }) => {
            voiceMessageStatusManager.setCurrentTime(parentMessage.channelUrl, parentMessage.messageId, stopped ? 0 : currentTime);
            if (seekFinished) {
              setState(prevState => ({
                ...prevState,
                currentTime: stopped ? 0 : currentTime,
                duration
              }));
            }
          });
          const forState = playerService.addStateListener(state => {
            switch (state) {
              case 'preparing':
                setState(prevState => ({
                  ...prevState,
                  status: 'preparing'
                }));
                break;
              case 'playing':
                setState(prevState => ({
                  ...prevState,
                  status: 'playing'
                }));
                break;
              case 'idle':
              case 'paused':
                {
                  setState(prevState => ({
                    ...prevState,
                    status: 'paused'
                  }));
                  break;
                }
              case 'stopped':
                setState(prevState => ({
                  ...prevState,
                  status: 'paused'
                }));
                break;
            }
          });
          playerUnsubscribes.current.push(forPlayback, forState);
          await playerService.play(parentMessage.url);
          if (shouldSeekToTime) {
            await playerService.seek(state.currentTime);
            seekFinished = true;
          }
        }
      }
    },
    ...props
  };
  const userMessageProps = {
    renderRegexTextChildren: message => {
      if (mentionManager.shouldUseMentionedMessageTemplate(message, sbOptions.uikit.groupChannel.channel.enableMention)) {
        return message.mentionedMessageTemplate ?? '';
      } else {
        return message.message;
      }
    },
    regexTextPatterns: [{
      regex: mentionManager.templateRegex,
      replacer({
        match,
        groups,
        parentProps,
        index,
        keyPrefix
      }) {
        var _parentMessage$mentio;
        const user = (_parentMessage$mentio = parentMessage.mentionedUsers) === null || _parentMessage$mentio === void 0 ? void 0 : _parentMessage$mentio.find(it => it.userId === groups[2]);
        if (user) {
          const mentionColor = !isMyMessage(parentMessage, currentUser === null || currentUser === void 0 ? void 0 : currentUser.userId) && user.userId === (currentUser === null || currentUser === void 0 ? void 0 : currentUser.userId) ? palette.onBackgroundLight01 : parentProps === null || parentProps === void 0 ? void 0 : parentProps.color;
          return /*#__PURE__*/React.createElement(Text, _extends({}, parentProps, {
            key: `${keyPrefix}-${index}`,
            color: mentionColor,
            onPress: () => {
              var _messageProps$onPress;
              return (_messageProps$onPress = messageProps.onPressMentionedUser) === null || _messageProps$onPress === void 0 ? void 0 : _messageProps$onPress.call(messageProps, user);
            },
            onLongPress: messageProps.onLongPress,
            suppressHighlighting: true,
            style: [parentProps === null || parentProps === void 0 ? void 0 : parentProps.style, {
              fontWeight: '700'
            }, user.userId === (currentUser === null || currentUser === void 0 ? void 0 : currentUser.userId) && {
              backgroundColor: palette.highlight
            }]
          }), `${mentionManager.asMentionedMessageText(user)}`);
        }
        return match;
      }
    }]
  };
  switch (getMessageType(props.parentMessage)) {
    case 'user':
      {
        return /*#__PURE__*/React.createElement(ThreadParentMessageUser, _extends({}, userMessageProps, messageProps));
      }
    case 'user.opengraph':
      {
        return /*#__PURE__*/React.createElement(ThreadParentMessageUserOg, _extends({}, userMessageProps, messageProps));
      }
    case 'file':
    case 'file.audio':
      {
        return /*#__PURE__*/React.createElement(ThreadParentMessageFile, messageProps);
      }
    case 'file.video':
      {
        return /*#__PURE__*/React.createElement(ThreadParentMessageFileVideo, _extends({
          fetchThumbnailFromVideoSource: uri => mediaService.getVideoThumbnail({
            url: uri,
            timeMills: 1000
          })
        }, messageProps));
      }
    case 'file.image':
      {
        return /*#__PURE__*/React.createElement(ThreadParentMessageFileImage, messageProps);
      }
    case 'file.voice':
      {
        return /*#__PURE__*/React.createElement(ThreadParentMessageFileVoice, _extends({
          durationMetaArrayKey: VOICE_MESSAGE_META_ARRAY_DURATION_KEY,
          initialCurrentTime: voiceMessageStatusManager.getCurrentTime(parentMessage.channelUrl, parentMessage.messageId),
          onUnmount: () => {
            if (isVoiceMessage(parentMessage) && playerService.uri === parentMessage.url) {
              resetPlayer().catch(_ => {});
            }
          }
        }, messageProps));
      }
    default:
      {
        return null;
      }
  }
};
export default /*#__PURE__*/React.memo(ThreadParentMessageRenderer);
//# sourceMappingURL=index.js.map