function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } return n; }, _extends.apply(null, arguments); }
import React, { useContext, useEffect } from 'react';
import { useToast } from '@sendbird/uikit-react-native-foundation';
import { useGroupChannelHandler } from '@sendbird/uikit-tools';
import { isDifferentChannel, useFreshCallback, useIsFirstMount } from '@sendbird/uikit-utils';
import ChannelMessageList from '../../../components/ChannelMessageList';
import { MESSAGE_FOCUS_ANIMATION_DELAY, MESSAGE_SEARCH_SAFE_SCROLL_DELAY } from '../../../constants';
import { useLocalization, useSendbirdChat } from '../../../hooks/useContext';
import { GroupChannelContexts } from '../module/moduleContext';
const GroupChannelMessageList = props => {
  const toast = useToast();
  const {
    STRINGS
  } = useLocalization();
  const {
    sdk,
    sbOptions,
    groupChannelFragmentOptions
  } = useSendbirdChat();
  const {
    setMessageToEdit,
    setMessageToReply
  } = useContext(GroupChannelContexts.Fragment);
  const {
    subscribe
  } = useContext(GroupChannelContexts.PubSub);
  const {
    flatListRef,
    lazyScrollToBottom,
    lazyScrollToIndex,
    onPressReplyMessageInThread
  } = useContext(GroupChannelContexts.MessageList);
  const isFirstMount = useIsFirstMount();
  const scrollToMessageWithCreatedAt = useFreshCallback((createdAt, focusAnimated, timeout) => {
    const foundMessageIndex = props.messages.findIndex(it => it.createdAt === createdAt);
    const isIncludedInList = foundMessageIndex > -1;
    if (isIncludedInList) {
      if (focusAnimated) {
        setTimeout(() => props.onUpdateSearchItem({
          startingPoint: createdAt
        }), MESSAGE_FOCUS_ANIMATION_DELAY);
      }
      lazyScrollToIndex({
        index: foundMessageIndex,
        animated: true,
        timeout
      });
    } else {
      if (props.channel.messageOffsetTimestamp <= createdAt) {
        if (focusAnimated) {
          props.onUpdateSearchItem({
            startingPoint: createdAt
          });
        }
        props.onResetMessageListWithStartingPoint(createdAt).catch(_ => {});
      } else {
        return false;
      }
    }
    return true;
  });
  const scrollToBottom = useFreshCallback(async (animated = false) => {
    if (props.hasNext()) {
      props.onUpdateSearchItem(undefined);
      props.onScrolledAwayFromBottom(false);
      await props.onResetMessageList().catch(_ => {});
      props.onScrolledAwayFromBottom(false);
      lazyScrollToBottom({
        animated
      });
    } else {
      lazyScrollToBottom({
        animated
      });
    }
  });
  useGroupChannelHandler(sdk, {
    onReactionUpdated(channel, event) {
      if (isDifferentChannel(channel, props.channel)) return;
      const recentMessage = props.messages[0];
      const isRecentMessage = recentMessage && recentMessage.messageId === event.messageId;
      const scrollReachedBottomAndCanScroll = !props.scrolledAwayFromBottom && !props.hasNext();
      if (isRecentMessage && scrollReachedBottomAndCanScroll) {
        lazyScrollToBottom({
          animated: true,
          timeout: 250
        });
      }
    }
  });
  useEffect(() => {
    return subscribe(({
      type,
      data
    }) => {
      switch (type) {
        case 'TYPING_BUBBLE_RENDERED':
        case 'MESSAGES_RECEIVED':
          {
            if (!props.scrolledAwayFromBottom) {
              scrollToBottom(true);
            }
            break;
          }
        case 'MESSAGES_UPDATED':
          {
            const lastMessage = props.channel.lastMessage;
            const [updatedMessage] = data.messages;
            const lastMessageUpdated = updatedMessage && lastMessage && lastMessage.messageId === updatedMessage.messageId;
            const isMaybeStreaming = props.channel.hasAiBot && lastMessageUpdated;
            if (isMaybeStreaming) {
              scrollToBottom(false);
            } else if (!props.scrolledAwayFromBottom && lastMessageUpdated) {
              scrollToBottom(true);
            }
            break;
          }
        case 'MESSAGE_SENT_SUCCESS':
        case 'MESSAGE_SENT_PENDING':
          {
            scrollToBottom(false);
            break;
          }
      }
    });
  }, [props.scrolledAwayFromBottom]);
  useEffect(() => {
    return groupChannelFragmentOptions.pubsub.subscribe(payload => {
      switch (payload.type) {
        case 'OVERRIDE_SEARCH_ITEM_STARTING_POINT':
          {
            scrollToMessageWithCreatedAt(payload.data.startingPoint, false, MESSAGE_SEARCH_SAFE_SCROLL_DELAY);
            break;
          }
      }
    });
  }, []);
  useEffect(() => {
    // Only trigger once when message list mount with initial props.searchItem
    // - Search screen + searchItem > mount message list
    // - Reset message list + searchItem > re-mount message list
    if (isFirstMount && props.searchItem) {
      scrollToMessageWithCreatedAt(props.searchItem.startingPoint, false, MESSAGE_SEARCH_SAFE_SCROLL_DELAY);
    }
  }, [isFirstMount]);
  const onPressParentMessage = useFreshCallback((parentMessage, childMessage) => {
    if (onPressReplyMessageInThread && sbOptions.uikit.groupChannel.channel.replyType === 'thread' && sbOptions.uikit.groupChannel.channel.threadReplySelectType === 'thread') {
      if (parentMessage.createdAt >= props.channel.messageOffsetTimestamp) {
        onPressReplyMessageInThread(parentMessage, childMessage.createdAt);
      } else {
        toast.show(STRINGS.TOAST.FIND_PARENT_MSG_ERROR, 'error');
      }
    } else {
      const canScrollToParent = scrollToMessageWithCreatedAt(parentMessage.createdAt, true, 0);
      if (!canScrollToParent) toast.show(STRINGS.TOAST.FIND_PARENT_MSG_ERROR, 'error');
    }
  });
  return /*#__PURE__*/React.createElement(ChannelMessageList, _extends({}, props, {
    ref: flatListRef,
    onReplyMessage: setMessageToReply,
    onReplyInThreadMessage: setMessageToReply,
    onEditMessage: setMessageToEdit,
    onPressParentMessage: onPressParentMessage,
    onPressNewMessagesButton: scrollToBottom,
    onPressScrollToBottomButton: scrollToBottom
  }));
};
export default /*#__PURE__*/React.memo(GroupChannelMessageList);
//# sourceMappingURL=GroupChannelMessageList.js.map